#! /usr/bin/env python 
# -*- coding: utf-8 -*-
# by Hans Schou <chlor@schou.dk> 2014-01-15
#
# Syntax example:
#   ./svg.py > python.svg

import math, sys

# In the code the term 'fraction' is equal
# to a fraction of a cicle. Fraction = 1 = 360° = 2*pi

toothCount = 8
roundValues = True
RADIUS = 300.0
radius = RADIUS * 3/4
innerRad = RADIUS * 9/32 # aprx ~ 1/4
cornerRadius = 4/RADIUS
angelStart = 1.0/4 + 1.0/(toothCount*2)
angelToothTop = 1.0/(toothCount*3)
angelToothBottom = 1.0/(toothCount*3)
angelToothEdge = (1.0/toothCount - angelToothTop - angelToothBottom) / 2

vectorsTooth = [ {"rad":RADIUS, "ang":angelToothEdge}, {"rad":RADIUS, "ang":angelToothTop}, {"rad":radius, "ang":angelToothEdge} ];

def polarGearLogo():
	angel = angelStart
	p = []
	p.append( dictRadFraction(innerRad, angel) )
	p.append( dictRadFraction(radius, angel) )
	# Draw half tooth space
	angel += angelToothBottom / 2
	p.append( dictRadFraction(radius, angel) )
	n = toothCount - 1 # one tooth is missing on the gear
	while (n > 0):
		# Draw one tooth on the gear
		for pnt in vectorsTooth:
			angel += pnt['ang']
			p.append( dictRadFraction(pnt['rad'], angel) )
		# Draw one space between 2 tooths, or if last point draw a half space
		angel += angelToothBottom / (1 if n > 1 else 2)
		p.append( dictRadFraction(radius, angel) )
		n -= 1
	p.append( dictRadFraction(radius, angel) )
	# Draw inner circle counter clock wise
	p.append( dictRadFraction(innerRad, angel) )
	toothDiv = 3
	n = (toothCount-1)*toothDiv
	while (n > 0):
		angel -= 1.0/(toothCount*toothDiv)
		p.append( dictRadFraction(innerRad, angel) )
		n -= 1
	return p

# Convert radius and fraction to dictionary
# Return dictionary of 'r' and 'f'
def dictRadFraction(rad, fract):
	return { "r": rad, "f": fract }

# Vector in polar coordinate to cartesian coordinate
# Note: The angel is a fraction of a cicle not radians
# Return: Cartesian coordinates dictionary
def polarToCartesian(polar, offset):
	c = []
	for pol in polar:
		c.append( {"x": offset['x'] + pol['r'] * math.cos(pol['f'] * math.pi*2), "y": offset['y'] + pol['r'] * math.sin(pol['f'] * math.pi*2)} );
	return c

polar = polarGearLogo()
cartesian = polarToCartesian(polar, {'x':RADIUS,'y':RADIUS})
s = "<svg xmlns=\"http://www.w3.org/2000/svg\">"
s += "<title>OSHW symetrical Logo - python script</title>"
s += "<path fill=\"#0099B0\" stroke=\"#18284f\" stroke-width=\"10\" "
pnt = cartesian.pop(0)
s += "d=\"M%f,%fL" % (pnt['x'],pnt['y'])
for pnt in cartesian:
	s += "%f,%f " % (pnt['x'], pnt['y'])
s += "z\"/></svg>"
print s

